@@ -5,19 +5,48 @@ import time
 import curses
 from collections import OrderedDict
 
+import os
 import six
 import pytest
 import requests
+from six.moves import reload_module
 
 from rtv import exceptions
-from rtv.objects import Color, Controller, Navigator, Command, KeyMap, \
-    curses_session
+from rtv.objects import Controller, Navigator, Command, KeyMap, \
+    curses_session, patch_webbrowser
 
 try:
     from unittest import mock
 except ImportError:
     import mock
 
+# webbrowser's command to check if a file exists is different for py2/py3
+if six.PY3:
+    mock_isfile = mock.patch('shutil.which', return_value=None)
+else:
+    mock_isfile = mock.patch('os.path.isfile', return_value=None)
+
+
+@mock.patch.dict(os.environ, {'BROWSER': 'safari'})
+@mock.patch('sys.platform', 'darwin')
+@mock_isfile
+def test_patch_webbrowser(*_):
+
+    # Make sure that webbrowser re-generates the browser list using the
+    # mocked environment
+    import webbrowser
+    webbrowser = reload_module(webbrowser)
+
+    # By default, we expect that BROWSER will be loaded as a generic browser
+    # This is because "safari" is not a valid script in the system PATH
+    assert isinstance(webbrowser.get(), webbrowser.GenericBrowser)
+
+    # After patching, the default webbrowser should now be interpreted as an
+    # OSAScript browser
+    patch_webbrowser()
+    assert isinstance(webbrowser.get(), webbrowser.MacOSXOSAScript)
+    assert webbrowser._tryorder[0] == 'safari'
+
 
 @pytest.mark.parametrize('use_ascii', [True, False])
 def test_objects_load_screen(terminal, stdscr, use_ascii):
@@ -160,21 +189,6 @@ def test_objects_load_screen_nested_complex(terminal, stdscr, use_ascii):
     stdscr.subwin.addstr.assert_called_once_with(1, 1, error_message)
 
 
-def test_objects_color(stdscr):
-
-    colors = ['RED', 'GREEN', 'YELLOW', 'BLUE', 'MAGENTA', 'CYAN', 'WHITE']
-
-    # Check that all colors start with the default value
-    for color in colors:
-        assert getattr(Color, color) == curses.A_NORMAL
-
-    Color.init()
-
-    # Check that all colors are populated
-    for color in colors:
-        assert getattr(Color, color) == 23
-
-
 def test_objects_curses_session(stdscr):
 
     # Normal setup and cleanup
